<?php
/**
 * Plugin Name: TelegaPay WP
 * Plugin URI: https://telegapay.com
 * Description: Интеграция с платежной системой TelegaPay для приема P2P платежей
 * Version: 1.0.2
 * Author: TelegaPay
 * Author URI: https://telegapay.com
 * Text Domain: telegapay
 */

if (!defined('ABSPATH')) {
    exit;
}

define('TELEGAPAY_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('TELEGAPAY_PLUGIN_URL', plugin_dir_url(__FILE__));
define('TELEGAPAY_VERSION', '1.0.2');

class TelegaPay {
    private static $instance = null;
    private $api_key = '';
    private $api_endpoint = 'https://app.telegapay.pro/api/v1';

    public function __construct() {
        $this->load_settings();
        add_action('admin_menu', array($this, 'add_settings_page'));
        add_action('admin_init', array($this, 'register_settings'));
        add_action('wp_enqueue_scripts', array($this, 'enqueue_scripts'));
        add_shortcode('telegapay_button', array($this, 'payment_button_shortcode'));
        add_action('wp_ajax_telegapay_create_payment', array($this, 'ajax_create_payment'));
        add_action('wp_ajax_nopriv_telegapay_create_payment', array($this, 'ajax_create_payment'));
    }

    public static function get_instance() {
        if (null === self::$instance) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    private function load_settings() {
        $settings = get_option('telegapay_settings', array());
        if (isset($settings['api_key'])) {
            $this->api_key = $settings['api_key'];
        }
        if (isset($settings['api_endpoint']) && !empty($settings['api_endpoint'])) {
            $this->api_endpoint = $settings['api_endpoint'];
        }
    }

    public function enqueue_scripts() {
        wp_register_script(
            'telegapay-js',
            TELEGAPAY_PLUGIN_URL . 'assets/js/telegapay.js',
            array('jquery'),
            TELEGAPAY_VERSION,
            true
        );
        wp_localize_script('telegapay-js', 'telegapay_params', array(
            'ajax_url' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('telegapay-nonce')
        ));
        wp_register_style(
            'telegapay-css',
            TELEGAPAY_PLUGIN_URL . 'assets/css/telegapay.css',
            array(),
            TELEGAPAY_VERSION
        );
    }

    public function add_settings_page() {
        add_options_page(
            'TelegaPay Настройки',
            'TelegaPay',
            'manage_options',
            'telegapay-settings',
            array($this, 'settings_page_content')
        );
    }

    public function register_settings() {
        register_setting('telegapay_options_group', 'telegapay_settings', array($this, 'sanitize_settings'));
        add_settings_section('telegapay_main_section', 'Настройки API', array($this, 'section_callback'), 'telegapay-settings');
        add_settings_field('api_key', 'API Ключ', array($this, 'api_key_callback'), 'telegapay-settings', 'telegapay_main_section');
        add_settings_field('api_endpoint', 'API Эндпоинт', array($this, 'api_endpoint_callback'), 'telegapay-settings', 'telegapay_main_section');
        add_settings_field('default_currency', 'Валюта по умолчанию', array($this, 'default_currency_callback'), 'telegapay-settings', 'telegapay_main_section');
    }

    public function sanitize_settings($input) {
        $new_input = array();
        if (isset($input['api_key'])) {
            $new_input['api_key'] = sanitize_text_field($input['api_key']);
        }
        if (isset($input['api_endpoint'])) {
            $new_input['api_endpoint'] = esc_url_raw($input['api_endpoint']);
        }
        if (isset($input['default_currency'])) {
            $new_input['default_currency'] = sanitize_text_field($input['default_currency']);
        }
        return $new_input;
    }

    public function section_callback() {
        echo '<p>Настройте интеграцию с API TelegaPay. API ключ можно получить в <a href="https://app.telegapay.pro" target="_blank">личном кабинете TelegaPay</a>.</p>';
    }

    public function api_key_callback() {
        $settings = get_option('telegapay_settings', array());
        $api_key = isset($settings['api_key']) ? $settings['api_key'] : '';
        printf('<input type="text" id="api_key" name="telegapay_settings[api_key]" value="%s" class="regular-text" required />', esc_attr($api_key));
    }

    public function api_endpoint_callback() {
        $settings = get_option('telegapay_settings', array());
        $api_endpoint = isset($settings['api_endpoint']) ? $settings['api_endpoint'] : 'https://app.telegapay.pro/api/v1';
        printf('<input type="url" id="api_endpoint" name="telegapay_settings[api_endpoint]" value="%s" class="regular-text" />', esc_attr($api_endpoint));
        echo '<p class="description">Для тестов используйте эндпоинт https://testapp.telegapay.pro/api/v1</p>';
    }

    public function default_currency_callback() {
        $settings = get_option('telegapay_settings', array());
        $default_currency = isset($settings['default_currency']) ? $settings['default_currency'] : 'RUB';
        $currencies = array('RUB' => 'Российский рубль (₽)', 'USD' => 'Доллар США ($)', 'EUR' => 'Евро (€)', 'USDT' => 'Tether (USDT)');
        echo '<select id="default_currency" name="telegapay_settings[default_currency]">';
        foreach ($currencies as $code => $name) {
            printf('<option value="%s" %s>%s</option>', esc_attr($code), selected($default_currency, $code, false), esc_html($name));
        }
        echo '</select>';
    }

    public function settings_page_content() {
        if (!current_user_can('manage_options')) {
            return;
        }
        ?>
        <div class="wrap">
            <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
            <form method="post" action="options.php">
                <?php
                settings_fields('telegapay_options_group');
                do_settings_sections('telegapay-settings');
                submit_button('Сохранить настройки');
                ?>
            </form>
            <hr>
            <h2>Использование шорткода</h2>
            <p>Используйте следующий шорткод для добавления кнопки оплаты на страницу:</p>
            <pre>[telegapay_button amount="100" currency="RUB" description="Оплата заказа" button_text="Оплатить"]</pre>
            <h3>Доступные атрибуты</h3>
            <ul>
                <li><code>amount</code> - Сумма платежа (обязательно)</li>
                <li><code>currency</code> - Код валюты (по умолчанию: RUB)</li>
                <li><code>description</code> - Описание платежа</li>
                <li><code>button_text</code> - Текст кнопки (по умолчанию: "Оплатить")</li>
                <li><code>button_class</code> - Дополнительные CSS классы для кнопки</li>
                <li><code>payment_method</code> - Предпочтительный метод оплаты (необязательно)</li>
                <li><code>user_id</code> - ID пользователя для отслеживания</li>
            </ul>
        </div>
        <div class="postbox">
            <h3 class="hndle">Настройка вебхука</h3>
            <div class="inside">
                <p>Для получения уведомлений о статусе платежей, укажите в настройках TelegaPay следующий URL вебхука:</p>
                <input type="text" class="large-text code" value="<?php echo esc_url(rest_url('telegapay/v1/webhook')); ?>" readonly />
                <p class="description">Скопируйте этот URL и вставьте его в настройках вашего магазина в TelegaPay.</p>
            </div>
        </div>
        <?php
    }

    public function payment_button_shortcode($atts) {
        wp_enqueue_script('telegapay-js');
        wp_enqueue_style('telegapay-css');
        if (empty($this->api_key)) {
            if (current_user_can('manage_options')) {
                return '<div class="telegapay-error">API ключ TelegaPay не настроен. Пожалуйста, настройте его в <a href="' . admin_url('options-general.php?page=telegapay-settings') . '">настройках плагина</a>.</div>';
            }
            return '';
        }
        $settings = get_option('telegapay_settings', array());
        $default_currency = isset($settings['default_currency']) ? $settings['default_currency'] : 'RUB';
        $defaults = array(
            'amount' => '',
            'currency' => $default_currency,
            'description' => 'Оплата',
            'button_text' => 'Оплатить',
            'button_class' => 'telegapay-button',
            'payment_method' => '',
            'user_id' => is_user_logged_in() ? 'wp_' . get_current_user_id() : 'guest_' . uniqid(),
        );
        $atts = shortcode_atts($defaults, $atts, 'telegapay_button');
        if (empty($atts['amount']) || !is_numeric($atts['amount'])) {
            return '<div class="telegapay-error">Ошибка: необходимо указать корректную сумму платежа.</div>';
        }
        $button_id = 'telegapay-button-' . wp_rand(1000, 9999);
        $html = '<button id="' . esc_attr($button_id) . '" class="' . esc_attr($atts['button_class']) . '" data-amount="' . esc_attr($atts['amount']) . '" data-currency="' . esc_attr($atts['currency']) . '" data-description="' . esc_attr($atts['description']) . '" data-payment-method="' . esc_attr($atts['payment_method']) . '" data-user-id="' . esc_attr($atts['user_id']) . '">' . esc_html($atts['button_text']) . '</button>';
        $html .= '<div id="' . esc_attr($button_id) . '-loader" class="telegapay-loader" style="display: none;"></div>';
        return $html;
    }

    public function ajax_create_payment() {
        check_ajax_referer('telegapay-nonce', 'nonce');
        if (empty($_POST['amount']) || !is_numeric($_POST['amount'])) {
            wp_send_json_error(array('message' => 'Необходимо указать корректную сумму платежа'));
            wp_die();
        }
        $amount = floatval($_POST['amount']);
        $currency = sanitize_text_field($_POST['currency']);
        $description = sanitize_text_field($_POST['description']);
        $payment_method = sanitize_text_field($_POST['payment_method']);
        $user_id = sanitize_text_field($_POST['user_id']);
        $data = array(
            'amount' => $amount,
            'currency' => $currency,
            'description' => $description,
            'user_id' => $user_id
        );
        if (!empty($payment_method)) {
            $data['payment_method'] = $payment_method;
        }
        $response = $this->make_api_request('create_paylink', $data);
        if (is_wp_error($response)) {
            wp_send_json_error(array('message' => 'Ошибка при создании платежа: ' . $response->get_error_message()));
            wp_die();
        }
        $body = wp_remote_retrieve_body($response);
        $result = json_decode($body, true);
        if (isset($result['success']) && $result['success'] && isset($result['payment_url'])) {
            telegapay_save_payment_info(
                $result['transaction_id'],
                $amount,
                $currency,
                isset($result['amount_usdt']) ? $result['amount_usdt'] : 0,
                'awaiting',
                $result['payment_url'],
                $description,
                $user_id
            );
            wp_send_json_success(array(
                'payment_url' => $result['payment_url'],
                'transaction_id' => $result['transaction_id']
            ));
        } else {
            wp_send_json_error(array('message' => 'Неизвестная ошибка при создании платежа'));
        }
        wp_die();
    }

    private function make_api_request($endpoint, $data) {
        $url = trailingslashit($this->api_endpoint) . $endpoint;
        $args = array(
            'method' => 'POST',
            'timeout' => 30,
            'redirection' => 5,
            'httpversion' => '1.1',
            'headers' => array(
                'Content-Type' => 'application/json',
                'X-API-Key' => $this->api_key
            ),
            'body' => json_encode($data),
            'cookies' => array()
        );
        return wp_remote_request($url, $args);
    }
}

function telegapay_save_payment_info($transaction_id, $amount, $currency, $amount_usdt, $status, $payment_url, $description, $user_id) {
    global $wpdb;
    $table_name = $wpdb->prefix . 'telegapay_payments';
    $existing = $wpdb->get_row($wpdb->prepare("SELECT * FROM $table_name WHERE transaction_id = %s", $transaction_id));
    if ($existing) {
        $wpdb->update(
            $table_name,
            ['status' => $status, 'updated_at' => current_time('mysql')],
            ['transaction_id' => $transaction_id],
            ['%s', '%s'],
            ['%s']
        );
    } else {
        $order_id = (strpos($user_id, 'order_') === 0) ? substr($user_id, 6) : '';
        $wpdb->insert(
            $table_name,
            [
                'transaction_id' => $transaction_id,
                'order_id' => $order_id,
                'user_id' => $user_id,
                'amount' => $amount,
                'currency' => $currency,
                'amount_usdt' => $amount_usdt,
                'status' => $status,
                'payment_url' => $payment_url,
                'description' => $description,
                'created_at' => current_time('mysql'),
                'updated_at' => current_time('mysql')
            ],
            ['%s', '%s', '%s', '%f', '%s', '%f', '%s', '%s', '%s', '%s', '%s']
        );
    }
}

function telegapay_init() {
    return TelegaPay::get_instance();
}

add_action('plugins_loaded', 'telegapay_init');

function telegapay_register_webhook_endpoint() {
    register_rest_route('telegapay/v1', '/webhook', [
        'methods' => 'POST',
        'callback' => 'telegapay_process_webhook',
        'permission_callback' => '__return_true'
    ]);
}
add_action('rest_api_init', 'telegapay_register_webhook_endpoint');

function telegapay_process_webhook($request) {
    $params = $request->get_params();
    error_log('TelegaPay webhook received: ' . json_encode($params));
    if (!isset($params['transaction_id']) || !isset($params['status'])) {
        return new WP_REST_Response(['success' => false, 'message' => 'Missing required fields'], 400);
    }
    $transaction_id = sanitize_text_field($params['transaction_id']);
    $status = sanitize_text_field($params['status']);
    $amount = isset($params['amount']) ? floatval($params['amount']) : 0;
    $amount_usdt = isset($params['amount_usdt']) ? floatval($params['amount_usdt']) : 0;
    $currency = isset($params['currency']) ? sanitize_text_field($params['currency']) : '';
    $completed_at = isset($params['completed_at']) ? sanitize_text_field($params['completed_at']) : '';
    $webhook_id = telegapay_save_webhook_log($params);
    $updated = telegapay_update_transaction_status($transaction_id, $status, $params);
    if ($updated) {
        do_action('telegapay_payment_status_changed', $transaction_id, $status, $params);
        return new WP_REST_Response(['success' => true, 'message' => 'Webhook processed successfully', 'webhook_id' => $webhook_id], 200);
    }
    return new WP_REST_Response(['success' => false, 'message' => 'Transaction not found or already processed'], 404);
}

function telegapay_save_webhook_log($data) {
    global $wpdb;
    $table_name = $wpdb->prefix . 'telegapay_webhook_logs';
    if ($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {
        $charset_collate = $wpdb->get_charset_collate();
        $sql = "CREATE TABLE $table_name (
            id mediumint(9) NOT NULL AUTO_INCREMENT,
            transaction_id varchar(100) NOT NULL,
            status varchar(50) NOT NULL,
            data text NOT NULL,
            created_at datetime DEFAULT CURRENT_TIMESTAMP NOT NULL,
            PRIMARY KEY  (id)
        ) $charset_collate;";
        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);
    }
    $wpdb->insert(
        $table_name,
        [
            'transaction_id' => isset($data['transaction_id']) ? $data['transaction_id'] : '',
            'status' => isset($data['status']) ? $data['status'] : '',
            'data' => json_encode($data),
            'created_at' => current_time('mysql')
        ],
        ['%s', '%s', '%s', '%s']
    );
    return $wpdb->insert_id;
}

function telegapay_update_transaction_status($transaction_id, $status, $data) {
    global $wpdb;
    $table_name = $wpdb->prefix . 'telegapay_payments';
    $payment = $wpdb->get_row($wpdb->prepare("SELECT * FROM $table_name WHERE transaction_id = %s", $transaction_id));
    if (!$payment) {
        return false;
    }
    $result = $wpdb->update(
        $table_name,
        ['status' => $status, 'updated_at' => current_time('mysql')],
        ['transaction_id' => $transaction_id],
        ['%s', '%s'],
        ['%s']
    );
    if (isset($payment->order_id) && !empty($payment->order_id) && function_exists('wc_get_order')) {
        $order = wc_get_order($payment->order_id);
        if ($order) {
            if ($status === 'completed') {
                $order->payment_complete($transaction_id);
                $order->add_order_note(sprintf(__('Payment completed via TelegaPay. Transaction ID: %s', 'telegapay'), $transaction_id));
            } elseif ($status === 'cancelled') {
                $order->update_status('cancelled', sprintf(__('Payment cancelled via TelegaPay. Transaction ID: %s', 'telegapay'), $transaction_id));
            }
        }
    }
    return (bool) $result;
}

function telegapay_activate() {
    $assets_dir = TELEGAPAY_PLUGIN_DIR . 'assets';
    if (!file_exists($assets_dir)) {
        mkdir($assets_dir, 0755);
    }
    $js_dir = $assets_dir . '/js';
    if (!file_exists($js_dir)) {
        mkdir($js_dir, 0755);
    }
    $css_dir = $assets_dir . '/css';
    if (!file_exists($css_dir)) {
        mkdir($css_dir, 0755);
    }
    $js_file = $js_dir . '/telegapay.js';
    if (!file_exists($js_file)) {
        $js_content = <<<EOT
jQuery(document).ready(function($) {
    if ($('#telegapay-modal').length === 0) {
        $('body').append(`
            <div id="telegapay-modal" style="display: none;">
                <div class="telegapay-modal-overlay"></div>
                <div class="telegapay-modal-container">
                    <div class="telegapay-modal-header">
                        <span class="telegapay-modal-title">Оплата</span>
                        <span class="telegapay-modal-close">&times;</span>
                    </div>
                    <div class="telegapay-modal-body">
                        <iframe id="telegapay-payment-frame" frameborder="0" allowtransparency="true"></iframe>
                    </div>
                </div>
            </div>
        `);
    }
    $(document).on('click', '.telegapay-modal-close', function() {
        closePaymentModal();
    });
    $(document).on('click', '.telegapay-modal-overlay', function() {
        closePaymentModal();
    });
    function closePaymentModal() {
        $('#telegapay-modal').fadeOut(300);
        $('#telegapay-payment-frame').attr('src', '');
        $('body').css('overflow', 'auto');
    }
    function openPaymentModal(paymentUrl) {
        $('#telegapay-payment-frame').attr('src', paymentUrl);
        $('#telegapay-modal').fadeIn(300);
        $('body').css('overflow', 'hidden');
    }
    window.addEventListener('message', function(event) {
        if (event.origin === 'https://app.telegapay.pro') {
            try {
                const data = typeof event.data === 'string' ? JSON.parse(event.data) : event.data;
                if (data.action === 'payment_success') {
                    closePaymentModal();
                } else if (data.action === 'payment_cancel') {
                    closePaymentModal();
                } else if (data.action === 'payment_error') {
                    closePaymentModal();
                    alert('Произошла ошибка при обработке платежа: ' + data.message);
                }
            } catch (e) {
                console.error('Error processing message from payment form:', e);
            }
        }
    });
    $(document).on('click', '[id^=telegapay-button-]', function(e) {
        e.preventDefault();
        var button = $(this);
        var buttonId = button.attr('id');
        var loader = $('#' + buttonId + '-loader');
        button.prop('disabled', true);
        loader.show();
        var amount = button.data('amount');
        var currency = button.data('currency');
        var description = button.data('description');
        var paymentMethod = button.data('payment-method');
        var userId = button.data('user-id');
        $.ajax({
            url: telegapay_params.ajax_url,
            type: 'POST',
            data: {
                action: 'telegapay_create_payment',
                nonce: telegapay_params.nonce,
                amount: amount,
                currency: currency,
                description: description,
                payment_method: paymentMethod,
                user_id: userId
            },
            success: function(response) {
                button.prop('disabled', false);
                loader.hide();
                if (response.success && response.data.payment_url) {
                    openPaymentModal(response.data.payment_url);
                } else {
                    alert(response.data.message || 'Произошла ошибка при создании платежа');
                }
            },
            error: function() {
                button.prop('disabled', false);
                loader.hide();
                alert('Произошла ошибка при отправке запроса');
            }
        });
    });
});
EOT;
        file_put_contents($js_file, $js_content);
    }
    $css_file = $css_dir . '/telegapay.css';
    if (!file_exists($css_file)) {
        $css_content = <<<EOT
.telegapay-button {
    display: inline-block;
    padding: 10px 20px;
    background-color: #4CAF50;
    color: white;
    text-align: center;
    text-decoration: none;
    font-size: 16px;
    border: none;
    border-radius: 4px;
    cursor: pointer;
    transition: background-color 0.3s;
}
.telegapay-button:hover {
    background-color: #45a049;
}
.telegapay-button:disabled {
    background-color: #cccccc;
    cursor: not-allowed;
}
.telegapay-loader {
    display: inline-block;
    width: 20px;
    height: 20px;
    margin-left: 10px;
    border: 3px solid rgba(0, 0, 0, 0.1);
    border-radius: 50%;
    border-top-color: #4CAF50;
    animation: telegapay-spin 1s ease-in-out infinite;
}
@keyframes telegapay-spin {
    to { transform: rotate(360deg); }
}
.telegapay-error {
    padding: 10px;
    background-color: #f8d7da;
    color: #721c24;
    border: 1px solid #f5c6cb;
    border-radius: 4px;
    margin: 10px 0;
}
#telegapay-modal {
    position: fixed;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    z-index: 999999;
}
.telegapay-modal-overlay {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    background-color: rgba(0, 0, 0, 0.5);
}
.telegapay-modal-container {
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
    width: 90%;
    max-width: 500px;
    height: 90%;
    max-height: 650px;
    background-color: #fff;
    border-radius: 8px;
    box-shadow: 0 5px 15px rgba(0, 0, 0, 0.3);
    overflow: hidden;
    display: flex;
    flex-direction: column;
}
.telegapay-modal-header {
    display: flex;
    justify-content: space-between;
    align-items: center;
    padding: 15px 20px;
    background-color: #f5f5f5;
    border-bottom: 1px solid #e0e0e0;
}
.telegapay-modal-title {
    font-size: 18px;
    font-weight: bold;
    color: #333;
}
.telegapay-modal-close {
    font-size: 24px;
    font-weight: bold;
    color: #666;
    cursor: pointer;
    transition: color 0.3s;
}
.telegapay-modal-close:hover {
    color: #000;
}
.telegapay-modal-body {
    flex: 1;
    position: relative;
}
#telegapay-payment-frame {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    border: none;
}
@media screen and (max-width: 768px) {
    .telegapay-modal-container {
        width: 95%;
        height: 95%;
    }
}
EOT;
        file_put_contents($css_file, $css_content);
    }
}

function telegapay_create_tables() {
    global $wpdb;
    $charset_collate = $wpdb->get_charset_collate();
    $payments_table = $wpdb->prefix . 'telegapay_payments';
    $sql_payments = "CREATE TABLE $payments_table (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        transaction_id varchar(100) NOT NULL,
        order_id varchar(100),
        user_id varchar(100),
        amount decimal(15,2) NOT NULL,
        currency varchar(10) NOT NULL,
        amount_usdt decimal(15,6),
        status varchar(50) NOT NULL,
        payment_url text,
        description text,
        created_at datetime DEFAULT CURRENT_TIMESTAMP NOT NULL,
        updated_at datetime DEFAULT CURRENT_TIMESTAMP NOT NULL,
        PRIMARY KEY  (id),
        UNIQUE KEY transaction_id (transaction_id)
    ) $charset_collate;";
    $webhook_logs_table = $wpdb->prefix . 'telegapay_webhook_logs';
    $sql_webhook_logs = "CREATE TABLE $webhook_logs_table (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        transaction_id varchar(100) NOT NULL,
        status varchar(50) NOT NULL,
        data text NOT NULL,
        created_at datetime DEFAULT CURRENT_TIMESTAMP NOT NULL,
        PRIMARY KEY  (id)
    ) $charset_collate;";
    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql_payments);
    dbDelta($sql_webhook_logs);
}

register_activation_hook(__FILE__, 'telegapay_create_tables');
register_activation_hook(__FILE__, 'telegapay_activate');

function telegapay_add_settings_link($links) {
    $settings_link = '<a href="' . admin_url('options-general.php?page=telegapay-settings') . '">Настройки</a>';
    array_unshift($links, $settings_link);
    return $links;
}

function telegapay_add_admin_menu() {
    add_menu_page(
        'TelegaPay Платежи',
        'TelegaPay',
        'manage_options',
        'telegapay-payments',
        'telegapay_payments_page',
        'dashicons-money-alt',
        30
    );
}
add_action('admin_menu', 'telegapay_add_admin_menu');

function telegapay_payments_page() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'telegapay_payments';
    if ($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {
        echo '<div class="wrap"><h1>TelegaPay Платежи</h1>';
        echo '<div class="notice notice-error"><p>Таблица платежей не найдена. Пожалуйста, деактивируйте и снова активируйте плагин.</p></div>';
        echo '</div>';
        return;
    }
    $page = isset($_GET['paged']) ? max(1, intval($_GET['paged'])) : 1;
    $per_page = 20;
    $offset = ($page - 1) * $per_page;
    $total_items = $wpdb->get_var("SELECT COUNT(*) FROM $table_name");
    $total_pages = ceil($total_items / $per_page);
    $payments = $wpdb->get_results(
        $wpdb->prepare("SELECT * FROM $table_name ORDER BY created_at DESC LIMIT %d OFFSET %d", $per_page, $offset)
    );
    include TELEGAPAY_PLUGIN_DIR . 'templates/admin-payments.php';
}

function telegapay_ajax_check_status() {
    check_admin_referer('telegapay-check-status');
    if (!current_user_can('manage_options')) {
        wp_die('Доступ запрещен');
    }
    $transaction_id = isset($_GET['transaction_id']) ? sanitize_text_field($_GET['transaction_id']) : '';
    if (empty($transaction_id)) {
        wp_die('ID транзакции не указан');
    }
    $result = telegapay_check_payment_status($transaction_id);
    if (is_wp_error($result)) {
        wp_die('Ошибка при проверке статуса: ' . $result->get_error_message());
    }
    if (isset($result['success']) && $result['success']) {
        telegapay_update_transaction_status($transaction_id, $result['status'], $result);
        wp_redirect(admin_url('admin.php?page=telegapay-payments&status_updated=1'));
        exit;
    }
    wp_die('Не удалось получить статус платежа: ' . (isset($result['error']) ? $result['error'] : 'Неизвестная ошибка'));
}
add_action('wp_ajax_telegapay_check_status', 'telegapay_ajax_check_status');

function telegapay_check_payment_status($transaction_id) {
    $settings = get_option('telegapay_settings', array());
    $api_key = isset($settings['api_key']) ? $settings['api_key'] : '';
    $api_endpoint = isset($settings['api_endpoint']) ? $settings['api_endpoint'] : 'https://app.telegapay.pro/api/v1';
    if (empty($api_key)) {
        return new WP_Error('api_key_missing', 'API ключ не настроен');
    }
    $url = trailingslashit($api_endpoint) . 'check_status';
    $args = array(
        'method' => 'POST',
        'timeout' => 30,
        'redirection' => 5,
        'httpversion' => '1.1',
        'headers' => array(
            'Content-Type' => 'application/json',
            'X-API-Key' => $api_key
        ),
        'body' => json_encode(array('transaction_id' => $transaction_id)),
        'cookies' => array()
    );
    $response = wp_remote_request($url, $args);
    if (is_wp_error($response)) {
        return $response;
    }
    $body = wp_remote_retrieve_body($response);
    $result = json_decode($body, true);
    if (!$result) {
        return new WP_Error('invalid_response', 'Неверный формат ответа от API');
    }
    return $result;
}

add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'telegapay_add_settings_link');